@@ -12,7 +12,7 @@ from PIL import Image
 import re
 
 def sumdumbfun(x,y): # this is only here to test the package during development
-    return x*y*y
+    return x*y*y*y*y
 
 ## RootDir establishes the export and data folder structure
 def RootDir(corename, Formation_names):
